@@ -5,11 +5,12 @@ use 5.006;
 use strict;
 use warnings;
 
+use Carp;
+
 use base qw{ PPIx::QuoteLike::Token };
 
-use PPIx::QuoteLike::Constant qw{ @CARP_NOT };
+our $VERSION = '0.001';
 
-our $VERSION = '0.022_01';
 
 1;
 
@@ -31,6 +32,7 @@ L<PPIx::QuoteLike::Token|PPIx::QuoteLike::Token>.
 
 C<PPIx::QuoteLike::Token::String> has no descendants.
 
+
 =head1 DESCRIPTION
 
 This Perl class represents a literal, uninterpolated string.
@@ -40,6 +42,7 @@ This Perl class represents a literal, uninterpolated string.
 This class supports no public methods in addition to those of its
 superclass.
 
+
 =head1 SEE ALSO
 
 L<PPIx::QuoteLike::Token|PPIx::QuoteLike::Token>.
@@ -47,9 +50,7 @@ L<PPIx::QuoteLike::Token|PPIx::QuoteLike::Token>.
 =head1 SUPPORT
 
 Support is by the author. Please file bug reports at
-L<https://rt.cpan.org/Public/Dist/Display.html?Name=PPIx-QuoteLike>,
-L<https://github.com/trwyant/perl-PPIx-QuoteLike/issues>, or in
-electronic mail to the author.
+L<http://rt.cpan.org>, or in electronic mail to the author.
 
 =head1 AUTHOR
 
@@ -57,7 +58,7 @@ Thomas R. Wyant, III F<wyant at cpan dot org>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2016-2022 by Thomas R. Wyant, III
+Copyright (C) 2016 by Thomas R. Wyant, III
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl 5.10.0. For more details, see the full text
