@@ -1,15 +1,15 @@
 package PPIx::QuoteLike::Token::Unknown;
 
-use 5.006;
+use 5.008;
 
 use strict;
 use warnings;
 
+use Carp;
+
 use base qw{ PPIx::QuoteLike::Token };
 
-use PPIx::QuoteLike::Constant qw{ @CARP_NOT };
-
-our $VERSION = '0.022_01';
+our $VERSION = '0.001';
 
 1;
 
@@ -48,9 +48,7 @@ L<PPIx::QuoteLike::Token|PPIx::QuoteLike::Token>.
 =head1 SUPPORT
 
 Support is by the author. Please file bug reports at
-L<https://rt.cpan.org/Public/Dist/Display.html?Name=PPIx-QuoteLike>,
-L<https://github.com/trwyant/perl-PPIx-QuoteLike/issues>, or in
-electronic mail to the author.
+L<http://rt.cpan.org>, or in electronic mail to the author.
 
 =head1 AUTHOR
 
@@ -58,7 +56,7 @@ Thomas R. Wyant, III F<wyant at cpan dot org>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2016-2022 by Thomas R. Wyant, III
+Copyright (C) 2016 by Thomas R. Wyant, III
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl 5.10.0. For more details, see the full text
