@@ -5,11 +5,12 @@ use 5.006;
 use strict;
 use warnings;
 
+use Carp;
+
 use base qw{ PPIx::QuoteLike::Token };
 
-use PPIx::QuoteLike::Constant qw{ @CARP_NOT };
+our $VERSION = '0.001';
 
-our $VERSION = '0.022_01';
 
 sub significant {
     return 0;
@@ -35,6 +36,7 @@ L<PPIx::QuoteLike::Token|PPIx::QuoteLike::Token>.
 
 C<PPIx::QuoteLike::Token::Whitespace> has no descendants.
 
+
 =head1 DESCRIPTION
 
 This Perl class represents insignificant white space.
@@ -48,6 +50,7 @@ superclass. However, the following methods have been overridden:
 
 This method returns a false value.
 
+
 =head1 SEE ALSO
 
 L<PPIx::QuoteLike::Token|PPIx::QuoteLike::Token>.
@@ -55,9 +58,7 @@ L<PPIx::QuoteLike::Token|PPIx::QuoteLike::Token>.
 =head1 SUPPORT
 
 Support is by the author. Please file bug reports at
-L<https://rt.cpan.org/Public/Dist/Display.html?Name=PPIx-QuoteLike>,
-L<https://github.com/trwyant/perl-PPIx-QuoteLike/issues>, or in
-electronic mail to the author.
+L<http://rt.cpan.org>, or in electronic mail to the author.
 
 =head1 AUTHOR
 
@@ -65,7 +66,7 @@ Thomas R. Wyant, III F<wyant at cpan dot org>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2016-2022 by Thomas R. Wyant, III
+Copyright (C) 2016 by Thomas R. Wyant, III
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl 5.10.0. For more details, see the full text
